@@ -48,6 +48,26 @@ class Slack:
         """Return an instance of the update class."""
         return Update(self, args, auth)
 
+    #
+    # admin conversations
+    #
+    def admin_conversations_set_teams(self, channel_id, org_channel=False, target_team_ids=None, team_id=None):
+        """Set teams for a channel."""
+        params = {
+            "channel_id": channel_id,
+            "org_channel": org_channel,
+            "target_team_ids": target_team_ids,
+            "team_id": team_id,
+        }
+        return self.webclient.admin_conversations_setTeams(**params)
+
+    #
+    # admin teams
+    #
+    def admin_teams_list(self):
+        """Set teams for a channel."""
+        return self.webclient.admin_teams_list()
+
     #
     # admin usergroups
     #
