@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """Slack Update class file."""
-
 import re
 
+from bits.mongo import Mongo
 from .scim import SCIM
 
 
@@ -33,6 +33,12 @@ class Update:
         self.slack_users = None
         self.team_profile = None
 
+    def _auth_mongo(self):
+        """Return an authenticated Mongo class."""
+        mongo_db = self.auth.settings['mongo']['bitsdb']['db']
+        mongo_uri = self.auth.settings['mongo']['bitsdb']['uri']
+        return Mongo(mongo_uri, mongo_db)
+
     def _check_user(self, user):
         """Check a single user."""
         user_id = user["id"]
@@ -208,7 +214,7 @@ class Update:
 
     def _get_other_accounts(self):
         """Return a dict of other accounts from BITSdb."""
-        mongo = self.auth.mongo()
+        mongo = self._auth_mongo()
         other_accounts = {}
         for account in mongo.get_collection("other_accounts"):
             key = account.get("slack_username")
@@ -255,7 +261,8 @@ class Update:
         emails = []
         usergroup_ids = []
         syncs = []
-        for sync in self.auth.mongo().get_collection("slack_usergroup_sync"):
+        mongo = self._auth_mongo()
+        for sync in mongo.get_collection("slack_usergroup_sync"):
             email = sync["google_group"]
             usergroup_id = sync["slack_usergroup"]
             usergroup_name = sync["slack_usergroup_name"]
@@ -484,6 +491,7 @@ class Update:
         if not self.team_profile:
             self.team_profile = self.slack.get_team_profile().get("profile")
         self.github_profile_id = self._get_github_profile_field()
+        print(f"Profile ID: {self.github_profile_id}")
 
         if not self.people:
             if self.verbose:
@@ -507,14 +515,18 @@ class Update:
                 continue
 
             email = user["profile"].get("email")
+            print(f"Email: {email}")
 
             # skip people with no email address
             if email not in self.people:
+                print(f"Skipping user: {email}")
                 continue
 
             # get person and their github login
             person = self.people[email]
             github_login = person.get("github_login")
+            if github_login:
+                print(f"  GitHub Login: {github_login}")
 
             # check github profile field
             if github_login and self.github_profile_id:
@@ -541,6 +553,8 @@ class Update:
                     print(f"Updating GitHub Profile for: {email}...")
                     profile["fields"] = fields
                     self.slack.set_user_profile(user_id, profile)
+                else:
+                    print(f"  No update required for: {email}")
 
     def usergroups(self):
         """Update usergroups in Slack."""
@@ -593,7 +607,7 @@ class Update:
                         print(f"   + {email}")
                 if delete:
                     print(f"  Deleting {len(delete)} users:")
-                    for user_id in sorted(delete, key=lambda x: self.slack_users[x]["profile"]["email"].lower()):
+                    for user_id in sorted(delete, key=lambda x: self.slack_users[x]["profile"]["email"].lower() if x in self.slack_users else ""):
                         user = self.slack_users[user_id]
                         email = user["profile"]["email"].lower()
                         print(f"   - {email}")
